"""
The qiprofile-rest unit tests.

:Note: unlike the other OHSU QIN python projects, the qiprofile-rest
  tests are contained within the main qiprofile-rest package. The test
  module is thus contained in the qiprofile-rest source distribution.
  This allows other python projects to call the qiprofile-rest seed
  module to populate a test or demo database.
"""



import sys
import os
from subprocess import (Popen, PIPE, STDOUT)

APP = os.path.abspath(os.path.join(os.path.dirname(__file__), 'run.py'))
"""The Python script to run."""


def spawn():
    """
    Start the Quantitaive Imaging Profile REST server.
    
    :return: the completed process return code
    """
    # The cumbersome but apparently necessary idiom below is required to
    # continuously pipe the server output to the console
    # (cf. http://stackoverflow.com/questions/4417546/constantly-print-subprocess-output-while-process-is-running).
    proc = Popen(['python', APP], stdout=PIPE, stderr=STDOUT)
    while True:
        line = proc.stdout.readline()
        if line == '' and proc.poll() != None:
            break
        sys.stdout.write(line)
        sys.stdout.flush()
    out, _ = proc.communicate()
    rc = proc.returncode
    
    return rc



"""This ``settings`` file specifies the Eve configuration."""

import os

# The run environment default is production.
# Modify this by setting the NODE_ENV environment variable.
env = os.getenv('NODE_ENV') or 'production'
# The MongoDB database.
if env == 'production':
    MONGO_DBNAME = 'qiprofile'
else:
    MONGO_DBNAME = 'qiprofile_test'

# The DYNO environment variable is a useful Heroku detection
# proxy. If on Heroku, then set the Heroku demo variables.
if 'DYNO' in os.environ:
    MONGO_HOST = 'ds053139.mongolab.com'
    MONGO_PORT = 53139
    MONGO_USERNAME = 'seger'
    MONGO_PASSWORD = 'library1'

# Look for MongoDB environment overrides:

# The default host is localhost.
host = os.getenv('MONGO_HOST')
    MONGO_HOST = host

# The MongoDB port.
port = os.getenv('MONGO_PORT')
if port:
    MONGO_PORT = int(port)

# The MongoDB username.
user = os.getenv('MONGO_USERNAME')
if user:
    MONGO_USERNAME = user

# The MongoDB password.
pswd = os.getenv('MONGO_PASSWORD')
if pswd:
    MONGO_PASSWORD = pswd

# Even though the domain is defined by the Eve MongoEngine
# adapter, a DOMAIN setting is required by Eve. This setting
# is only used to avoid an Eve complaint about a missing domain.
DOMAIN = {'eve-mongoengine': {}}
